@@ -60,45 +60,48 @@ public:
         mWeight = mLdapClient->completionWeight();
     }
 
-    QString label() const Q_DECL_OVERRIDE
+    QString label() const override
     {
         return i18n("LDAP server %1", mLdapClient->server().host());
     }
 
-    QIcon icon() const Q_DECL_OVERRIDE
+    QIcon icon() const override
     {
         return QIcon::fromTheme(QStringLiteral("view-ldap-resource"));
     }
 
-    int completionWeight() const Q_DECL_OVERRIDE
+    int completionWeight() const override
     {
         return mWeight;
     }
 
-    void save(CompletionOrderWidget *) Q_DECL_OVERRIDE {
+    void save(CompletionOrderWidget *) override
+    {
         KConfig *config = KLDAP::LdapClientSearchConfig::config();
         KConfigGroup group(config, "LDAP");
         group.writeEntry(QStringLiteral("SelectedCompletionWeight%1").arg(mLdapClient->clientNumber()),
-        mWeight);
+                         mWeight);
         group.sync();
     }
 
-    bool hasEnableSupport() const Q_DECL_OVERRIDE
+    bool hasEnableSupport() const override
     {
         return false;
     }
 
-    bool isEnabled() const Q_DECL_OVERRIDE
+    bool isEnabled() const override
     {
         return true;
     }
 
-    void setIsEnabled(bool b) Q_DECL_OVERRIDE {
+    void setIsEnabled(bool b) override
+    {
         Q_UNUSED(b);
     }
 
 protected:
-    void setCompletionWeight(int weight) Q_DECL_OVERRIDE {
+    void setCompletionWeight(int weight) override
+    {
         mWeight = weight;
     }
 
@@ -111,7 +114,10 @@ class SimpleCompletionItem : public CompletionItem
 {
 public:
     SimpleCompletionItem(CompletionOrderWidget *editor, const QString &label, const QString &identifier, int weight, bool enableSupport = false)
-        : mLabel(label), mIdentifier(identifier), mHasEnableSupport(enableSupport), mEnabled(true)
+        : mLabel(label)
+        , mIdentifier(identifier)
+        , mHasEnableSupport(enableSupport)
+        , mEnabled(true)
     {
         KConfigGroup groupCompletionWeights(editor->configFile(), "CompletionWeights");
         mWeight = groupCompletionWeights.readEntry(mIdentifier, weight);
@@ -121,12 +127,12 @@ public:
         }
     }
 
-    bool isEnabled() const  Q_DECL_OVERRIDE
+    bool isEnabled() const override
     {
         return mEnabled;
     }
 
-    bool hasEnableSupport() const Q_DECL_OVERRIDE
+    bool hasEnableSupport() const override
     {
         return mHasEnableSupport;
     }
@@ -136,37 +142,39 @@ public:
         mIcon = icon;
     }
 
-    QString label() const Q_DECL_OVERRIDE
+    QString label() const override
     {
         return mLabel;
     }
 
-    QIcon icon() const Q_DECL_OVERRIDE
+    QIcon icon() const override
     {
         return mIcon;
     }
 
-    int completionWeight() const Q_DECL_OVERRIDE
+    int completionWeight() const override
     {
         return mWeight;
     }
 
-    void setIsEnabled(bool b) Q_DECL_OVERRIDE {
+    void setIsEnabled(bool b) override
+    {
         mEnabled = b;
     }
 
-    void save(CompletionOrderWidget *editor) Q_DECL_OVERRIDE {
+    void save(CompletionOrderWidget *editor) override
+    {
         KConfigGroup group(editor->configFile(), "CompletionWeights");
         group.writeEntry(mIdentifier, mWeight);
-        if (mHasEnableSupport)
-        {
+        if (mHasEnableSupport) {
             KConfigGroup groupEnabled(editor->configFile(), "CompletionEnabled");
-            //groupEnabled.writeEntry(mIdentifier, );
+            groupEnabled.writeEntry(mIdentifier, isEnabled());
         }
     }
 
 protected:
-    void setCompletionWeight(int weight) Q_DECL_OVERRIDE {
+    void setCompletionWeight(int weight) override
+    {
         mWeight = weight;
     }
 
@@ -199,9 +207,8 @@ public:
             setFlags(flags() | Qt::ItemIsUserCheckable);
             setCheckState(0, mItem->isEnabled() ? Qt::Checked : Qt::Unchecked);
         } else {
-            setFlags(flags() & ~ Qt::ItemIsUserCheckable);
+            setFlags(flags() & ~Qt::ItemIsUserCheckable);
         }
-
     }
 
     CompletionItem *item() const
@@ -209,12 +216,12 @@ public:
         return mItem;
     }
 
-    bool operator<(const QTreeWidgetItem &other) const Q_DECL_OVERRIDE
+    bool operator<(const QTreeWidgetItem &other) const override
     {
         const QTreeWidgetItem *otherItem = &other;
         const CompletionViewItem *completionItem = static_cast<const CompletionViewItem *>(otherItem);
         // item with weight 100 should be on the top -> reverse sorting
-        return (mItem->completionWeight() > completionItem->item()->completionWeight());
+        return mItem->completionWeight() > completionItem->item()->completionWeight();
     }
 
 private:
@@ -222,17 +229,16 @@ private:
 };
 
 CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
-    : QWidget(parent),
-      mConfig(QStringLiteral("kpimcompletionorder")),
-      mCollectionModel(nullptr),
-      mLdapSearch(nullptr),
-      mDirty(false)
+    : QWidget(parent)
+    , mConfig(QStringLiteral("kpimcompletionorder"))
+    , mCollectionModel(nullptr)
+    , mLdapSearch(nullptr)
+    , mDirty(false)
 {
     new CompletionOrderEditorAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this, QDBusConnection::ExportAdaptors);
 
-    QHBoxLayout *hbox = new QHBoxLayout;
-    setLayout(hbox);
+    QHBoxLayout *hbox = new QHBoxLayout(this);
 
     QWidget *page = new QWidget(this);
     QHBoxLayout *pageHBoxLayout = new QHBoxLayout(page);
@@ -259,6 +265,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mUpButton->setObjectName(QStringLiteral("mUpButton"));
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     mUpButton->setEnabled(false);   // b/c no item is selected yet
+    mUpButton->setToolTip(i18n("Move Up"));
     mUpButton->setFocusPolicy(Qt::StrongFocus);
 
     mDownButton = new QPushButton(upDownBox);
@@ -267,6 +274,7 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
     mDownButton->setObjectName(QStringLiteral("mDownButton"));
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
     mDownButton->setEnabled(false);   // b/c no item is selected yet
+    mDownButton->setToolTip(i18n("Move Down"));
     mDownButton->setFocusPolicy(Qt::StrongFocus);
 
     QWidget *spacer = new QWidget(upDownBox);
@@ -277,9 +285,10 @@ CompletionOrderWidget::CompletionOrderWidget(QWidget *parent)
             this, &CompletionOrderWidget::slotSelectionChanged);
     connect(mListView, &QTreeWidget::currentItemChanged,
             this, &CompletionOrderWidget::slotSelectionChanged);
+    connect(mListView, &QTreeWidget::itemChanged,
+            this, &CompletionOrderWidget::slotItemChanged);
     connect(mUpButton, &QAbstractButton::clicked, this, &CompletionOrderWidget::slotMoveUp);
     connect(mDownButton, &QAbstractButton::clicked, this, &CompletionOrderWidget::slotMoveDown);
-
 }
 
 CompletionOrderWidget::~CompletionOrderWidget()
@@ -295,8 +304,8 @@ void CompletionOrderWidget::save()
         group.deleteGroup();
 
         for (int itemIndex = 0; itemIndex < mListView->topLevelItemCount(); ++itemIndex) {
-            CompletionViewItem *item =
-                static_cast<CompletionViewItem *>(mListView->topLevelItem(itemIndex));
+            CompletionViewItem *item
+                = static_cast<CompletionViewItem *>(mListView->topLevelItem(itemIndex));
             item->item()->setCompletionWeight(w);
             item->item()->setIsEnabled(item->checkState(0) == Qt::Checked);
             item->item()->save(this);
@@ -326,7 +335,7 @@ void CompletionOrderWidget::addCompletionItemForCollection(const QModelIndex &in
         return;
     }
 
-    SimpleCompletionItem *item = new SimpleCompletionItem(this, index.data().toString(), QString::number(collection.id()), 60);
+    SimpleCompletionItem *item = new SimpleCompletionItem(this, index.data().toString(), QString::number(collection.id()), 60, true);
     item->setIcon(index.data(Qt::DecorationRole).value<QIcon>());
 
     new CompletionViewItem(mListView, item);
@@ -356,7 +365,7 @@ void CompletionOrderWidget::loadCompletionItems()
 
     Akonadi::CollectionFilterProxyModel *mimeTypeProxy = new Akonadi::CollectionFilterProxyModel(this);
     mimeTypeProxy->addMimeTypeFilters(QStringList() << KContacts::Addressee::mimeType()
-                                      << KContacts::ContactGroup::mimeType());
+                                                    << KContacts::ContactGroup::mimeType());
     mimeTypeProxy->setSourceModel(descendantsProxy);
     mimeTypeProxy->setExcludeVirtualCollections(true);
 
@@ -372,6 +381,7 @@ void CompletionOrderWidget::loadCompletionItems()
     addRecentAddressItem();
 
     mListView->sortItems(0, Qt::AscendingOrder);
+    mDirty = false;
 }
 
 void CompletionOrderWidget::setLdapClientSearch(KLDAP::LdapClientSearch *ldapSearch)
@@ -388,6 +398,11 @@ void CompletionOrderWidget::rowsInserted(const QModelIndex &parent, int start, i
     mListView->sortItems(0, Qt::AscendingOrder);
 }
 
+void CompletionOrderWidget::slotItemChanged()
+{
+    mDirty = true;
+}
+
 void CompletionOrderWidget::slotSelectionChanged()
 {
     QTreeWidgetItem *item = mListView->currentItem();
@@ -404,8 +419,8 @@ static void swapItems(CompletionViewItem *one, CompletionViewItem *other)
     otherCompletion->setCompletionWeight(oneCompletion->completionWeight());
     oneCompletion->setCompletionWeight(weight);
 
-    one->setItem(otherCompletion);
-    other->setItem(oneCompletion);
+    one->setItem(oneCompletion);
+    other->setItem(otherCompletion);
 }
 
 void CompletionOrderWidget::slotMoveUp()
@@ -419,8 +434,8 @@ void CompletionOrderWidget::slotMoveUp()
         return;
     }
     swapItems(item, above);
-    mListView->setCurrentItem(above, 0, QItemSelectionModel::Select | QItemSelectionModel::Current);
     mListView->sortItems(0, Qt::AscendingOrder);
+    slotSelectionChanged();
     mDirty = true;
 }
 
@@ -435,8 +450,7 @@ void CompletionOrderWidget::slotMoveDown()
         return;
     }
     swapItems(item, below);
-    mListView->setCurrentItem(below);
-    mListView->setCurrentItem(below, 0, QItemSelectionModel::Select | QItemSelectionModel::Current);
     mListView->sortItems(0, Qt::AscendingOrder);
+    slotSelectionChanged();
     mDirty = true;
 }
